# Import knihoven ArcPy a os pro práci s ArcGIS a operačním systémem
import arcpy
import os

# Nastavení pracovního adresáře (workspace), kde se budou ukládat a zpracovávat geodatabázové objekty
workspace = "C:\\Users\\lukas\\Documents\\ArcGIS\\Projects\\DP\\DP.gdb"
arcpy.env.workspace = workspace

# Cesta k souboru GeoJSON, který obsahuje polygon kampusu
geojson_path = "C:\\Users\\lukas\\Documents\\ArcGIS\\Projects\\DP\\czu_kampus.json"

# Cesta k souboru .lyrx, který reprezentuje vrstvu OpenStreetMap
lyr_file_path = "C:\\Users\\lukas\\Documents\\ArcGIS\\Projects\\DP\\OpenStreetMap.lyrx"

# Název výstupní feature class, která bude vytvořena z GeoJSON souboru
out_feature_class = "CZU_Polygon"

# Získání odkazu na aktuálně otevřený projekt v ArcGIS Pro
project = arcpy.mp.ArcGISProject("CURRENT")

# Získání první mapy v projektu (předpokládá se, že projekt obsahuje alespoň jednu mapu)
map = project.listMaps()[0]  

# Změna názvu mapy na "DP - Automatické zpracování dat"
map.name = "DP - Automatické zpracování dat"

# Odstranění všech stávajících vrstev v mapě
for lyr in map.listLayers():
    map.removeLayer(lyr)

# Přidání vrstvy OpenStreetMap do mapy
osm_layer = map.addDataFromPath(lyr_file_path)  # Vložení OSM vrstvy
osm_layer.name = "OpenStreetMap"  # Nastavení názvu vrstvy na "OpenStreetMap"

# Konverze GeoJSON souboru na feature class v geodatabázi
arcpy.conversion.JSONToFeatures(geojson_path, os.path.join(workspace, out_feature_class))

# Kontrola, zda je vrstva s názvem "CZU_Polygon" již přidána do mapy
czu_layer_exists = any(lyr.name == "CZU_Polygon" for lyr in map.listLayers())

# Pokud vrstva "CZU_Polygon" neexistuje, přidá se do mapy
if not czu_layer_exists:
    czu_layer = map.addDataFromPath(os.path.join(workspace, out_feature_class))

# Pokud vrstva "CZU_Polygon" existuje, nastaví se její průhlednost na 50 %
if czu_layer_exists:
    czu_layer = map.listLayers("CZU_Polygon")[0]  # Získání vrstvy
    czu_layer.transparency = 50  # Nastavení průhlednosti

# Uložení změn v projektu
project.save()
