# Import potřebných knihoven
from arcgis.gis import GIS
from arcgis.mapping import WebMap
import datetime

# Funkce pro aktualizaci existující GeoJSON položky
def update_existing_geojson_item(gis, item_name, geojson_path):
    # Vyhledání položky podle názvu a typu
    search_results = gis.content.search(query=f"title:{item_name}", item_type="GeoJson")
    if search_results:
        # Pokud položka existuje, vezme první výsledek
        existing_item = search_results[0]
        print(f"Existující položka nalezena: {existing_item.title} (ID: {existing_item.id})")
        # Aktualizuje položku novými daty z cesty geojson_path
        update_result = existing_item.update(data=geojson_path)
        if update_result:
            print(f"Položka '{existing_item.title}' byla úspěšně aktualizována.")
            return existing_item
        else:
            print(f"Aktualizace položky '{existing_item.title}' se nezdařila.")
            return None
    else:
        print(f"Položka s názvem '{item_name}' nebyla nalezena.")
        return None

# Funkce pro publikaci GeoJSON jako Feature Layer
def publish_geojson_as_feature_layer(existing_item):
    try:
        # Publikuje existující položku jako Feature Layer s možností přepsání
        published_layer = existing_item.publish(overwrite=True)
        print(f"Položka '{existing_item.title}' byla úspěšně publikována jako Feature Layer.")
        return published_layer
    except Exception as e:
        print(f"Publikace se nezdařila: {e}")
        return None

# Funkce pro přidání vrstvy do webové mapy
def add_layer_to_web_map(gis, feature_layer_item, web_map_title):
    # Vytvoří novou webovou mapu
    web_map = WebMap()
    # Přidá Feature Layer do mapy
    web_map.add_layer(feature_layer_item)
    # Nastaví vlastnosti pro webovou mapu
    web_map_properties = {'title': web_map_title + " " + datetime.datetime.now().strftime("%Y-%m-%d %H:%M"),
                          'snippet': 'Automatizovaná aktualizace.',
                          'tags': ['automatizace', 'CZU']}
    # Uloží webovou mapu s nastavenými vlastnostmi
    web_map_item = web_map.save(item_properties=web_map_properties)
    print(f"Web mapa '{web_map_title}' byla vytvořena s ID: {web_map_item.id}")
    return web_map_item

# Hlavní část skriptu
gis = GIS("home")  # Přihlášení do ArcGIS Online
geojson_path = "C:\\Users\\lukas\\Documents\\ArcGIS\\Projects\\DP\\czu_kampus.json"  # Cesta k GeoJSON souboru
item_name = "czu_kampus"  # Název položky

# Aktualizace existující položky
existing_item = update_existing_geojson_item(gis, item_name, geojson_path)
if existing_item:
    # Publikace aktualizované položky jako Feature Layer
    published_layer = publish_geojson_as_feature_layer(existing_item)
    if published_layer:
        # Vytvoření webové mapy s publikovanou vrstvou
        web_map_title = "DP - Automatizované zpracování dat"
        web_map_item = add_layer_to_web_map(gis, published_layer, web_map_title)
